package org.apereo.cas.support.saml.services;

import org.apereo.cas.services.RegisteredService;
import org.apereo.cas.support.saml.services.idp.metadata.SamlRegisteredServiceServiceProviderMetadataFacade;
import org.jasig.cas.client.util.URIBuilder;
import org.apereo.cas.logout.DefaultSingleLogoutServiceLogoutUrlBuilder;
import org.apereo.cas.services.ReloadableServicesManager;
import org.apereo.cas.support.saml.SamlProtocolConstants;
import org.apereo.cas.support.saml.services.idp.metadata.cache.SamlRegisteredServiceCachingMetadataResolver;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.saml2.metadata.SingleLogoutService;
import org.opensaml.saml.saml2.metadata.impl.SingleLogoutServiceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import java.net.URL;

/**
 * This is {@link SamlIdPSingleLogoutServiceLogoutUrlBuilder}.
 *
 * @author Misagh Moayyed
 * @since 5.0.0
 */
public class SamlIdPSingleLogoutServiceLogoutUrlBuilder extends DefaultSingleLogoutServiceLogoutUrlBuilder {

    /**
     * The Services manager.
     */
    @Autowired
    @Qualifier("servicesManager")
    protected ReloadableServicesManager servicesManager;

    /**
     * The Saml registered service caching metadata resolver.
     */
    @Autowired
    @Qualifier("defaultSamlRegisteredServiceCachingMetadataResolver")
    protected SamlRegisteredServiceCachingMetadataResolver samlRegisteredServiceCachingMetadataResolver;

    @Override
    public URL determineLogoutUrl(final RegisteredService registeredService,
                                  final org.apereo.cas.logout.SingleLogoutService singleLogoutService) {

        try {
            if (registeredService instanceof SamlRegisteredService) {
                final URIBuilder builder = new URIBuilder(singleLogoutService.getOriginalUrl());
                for (final URIBuilder.BasicNameValuePair basicNameValuePair : builder.getQueryParams()) {
                    if (basicNameValuePair.getName().equalsIgnoreCase(SamlProtocolConstants.PARAMETER_ENTITY_ID)) {
                        final String entityID = basicNameValuePair.getValue();

                        final SamlRegisteredServiceServiceProviderMetadataFacade adaptor =
                                SamlRegisteredServiceServiceProviderMetadataFacade.get(this.samlRegisteredServiceCachingMetadataResolver,
                                        SamlRegisteredService.class.cast(registeredService), entityID);

                        final String location = adaptor.getSingleLogoutService().getLocation();
                        return new URL(location);
                    }
                }
            }

        } catch (final Exception e) {
            logger.error(e.getMessage(), e);
        }
        return super.determineLogoutUrl(registeredService, singleLogoutService);
    }

    private static SingleLogoutService getSingleLogoutService(final String endpoint) {
        final SingleLogoutService acs = new SingleLogoutServiceBuilder().buildObject();
        acs.setBinding(SAMLConstants.SAML2_POST_BINDING_URI);
        acs.setLocation(endpoint);
        return acs;
    }
}
